@@ -122,16 +122,6 @@ void removeDatabaseIdsFromList(QList<QContactDetail> *dets)
     }
 }
 
-
-void dumpContactDetail(const QContactDetail &d)
-{
-    qWarning() << "++ ---------" << d.type();
-    QMap<int, QVariant> values = d.values();
-    foreach (int key, values.keys()) {
-        qWarning() << "    " << key << "=" << values.value(key);
-    }
-}
-
 int scoreForValuePair(const QVariant &removal, const QVariant &addition)
 {
     // work around some variant-comparison issues.
@@ -515,73 +505,6 @@ QList<QContactDetail> improveDelta(
     return finalModifications;
 }
 
-typedef QMap<int, QVariant> DetailMap;
-
-DetailMap detailValues(const QContactDetail &detail, bool includeProvenance = true, bool includeModifiable = true)
-{
-    DetailMap rv(detail.values());
-
-    if (!includeProvenance || !includeModifiable) {
-        DetailMap::iterator it = rv.begin();
-        while (it != rv.end()) {
-            if (!includeProvenance && it.key() == QContactDetail::FieldProvenance) {
-                it = rv.erase(it);
-            } else if (!includeModifiable && it.key() == QContactDetail__FieldModifiable) {
-                it = rv.erase(it);
-            } else {
-                ++it;
-            }
-        }
-    }
-
-    return rv;
-}
-
-static bool variantEqual(const QVariant &lhs, const QVariant &rhs)
-{
-    // Work around incorrect result from QVariant::operator== when variants contain QList<int>
-    static const int QListIntType = QMetaType::type("QList<int>");
-
-    const int lhsType = lhs.userType();
-    if (lhsType != rhs.userType()) {
-        return false;
-    }
-
-    if (lhsType == QListIntType) {
-        return (lhs.value<QList<int> >() == rhs.value<QList<int> >());
-    }
-    return (lhs == rhs);
-}
-
-static bool detailValuesEqual(const QContactDetail &lhs, const QContactDetail &rhs)
-{
-    const DetailMap lhsValues(detailValues(lhs, false, false));
-    const DetailMap rhsValues(detailValues(rhs, false, false));
-
-    if (lhsValues.count() != rhsValues.count()) {
-        return false;
-    }
-
-    // Because of map ordering, matching fields should be in the same order in both details
-    DetailMap::const_iterator lit = lhsValues.constBegin(), lend = lhsValues.constEnd();
-    DetailMap::const_iterator rit = rhsValues.constBegin();
-    for ( ; lit != lend; ++lit, ++rit) {
-        if (lit.key() != rit.key() || !variantEqual(*lit, *rit)) {
-            return false;
-        }
-    }
-
-    return true;
-}
-
-static bool detailsEquivalent(const QContactDetail &lhs, const QContactDetail &rhs)
-{
-    // Same as operator== except ignores differences in certain field values
-    if (lhs.type() != rhs.type())
-        return false;
-    return detailValuesEqual(lhs, rhs);
-}
-
 } // namespace
 
 const QSet<QContactDetail::DetailType>& QtContactsSqliteExtensions::defaultIgnorableDetailTypes()
